<h1 align="center">
    <img src="https://github.com/cribbslab/umiche/blob/main/img/UMIche-logo.png?raw=true" width="336" height="112">
    <br>
</h1>

[![Anaconda-Server Badge](https://anaconda.org/jianfeng_sun/umiche/badges/latest_release_date.svg)](https://anaconda.org/jianfeng_sun/umiche)
![PyPI](https://img.shields.io/pypi/v/umiche?logo=PyPI)
![Docker Image Version (latest)](https://img.shields.io/docker/v/2003100127/umiche)
![Docker Pulls](https://img.shields.io/docker/pulls/2003100127/umiche)
[![Anaconda-Server Badge](https://anaconda.org/jianfeng_sun/umiche/badges/version.svg)](https://anaconda.org/jianfeng_sun/umiche)
![](https://img.shields.io/docker/automated/2003100127/umiche.svg)
![](https://img.shields.io/github/stars/cribbslab/umiche?logo=GitHub&color=blue)
[![Downloads](https://pepy.tech/badge/umiche)](https://pepy.tech/project/umiche)
![example workflow](https://github.com/2003100127/umiche/actions/workflows/docs.yml/badge.svg)
![example workflow](https://github.com/2003100127/umiche/actions/workflows/pypi.yml/badge.svg)

<hr>

#### Platform

![Python](https://img.shields.io/badge/-Python-000?&logo=Python)
![Docker](https://img.shields.io/badge/-Docker-000?&logo=Docker)
![Anaconda](https://img.shields.io/badge/-Anaconda-000?&logo=Anaconda)
![PyPI](https://img.shields.io/badge/-PyPI-000?&logo=PyPI)

###### tags: `Unique molecular identifier`, `UMI deduplication`, `Count matrix`, `Genome analysis`,

## Overview

UMIche is a Python-based platform for improving multiplexing and demultiplexing of UMI-tagged sequencing data, which allows researchers to do knowledge discovery.

## 📔 Documentation

Please check how to use the full functionalities of UMIche in the documentation https://2003100127.github.io/umiche.

## 🔑 Installation

#### PyPI

[umiche homepage on PyPI](https://pypi.org/project/umiche/)

```shell
# create a conda environment
conda create --name umiche python=3.11

# activate the conda environment
conda activate umiche

# the latest version
pip install umiche --upgrade
```

#### Conda

[umiche homepage on Anaconda](https://anaconda.org/Jianfeng_Sun/umiche)

```shell
# create a conda environment
conda create --name umiche python=3.11

# activate the conda environment
conda activate umiche

# the latest version
conda install jianfeng_sun::umiche
```


#### Docker

[umiche homepage on Docker](https://hub.docker.com/r/2003100127/umiche)

```shell
docker pull 2003100127/umiche
```


#### Github

[umiche homepage on Github](https://github.com/2003100127/umiche)

```shell
# create a conda environment
conda create --name umiche python=3.11

# activate the conda environment
conda activate umiche

# create a folder
mkdir project

# go to the folder
cd project

# fetch UMIche repository with the latest version
git clone https://github.com/2003100127/umiche.git

# enter this repository
cd umiche

# do the following command
pip install .
# or
python setup.py install
```


## 📋 Citation

Please cite our work if you use Tresor in your research.
```angular2html
@article{umiche,
    title = {UMIche: a Python-based platform for improving multiplexing and demultiplexing of UMI-tagged sequencing data},
    author = {Jianfeng Sun},
    url = {https://github.com/2003100127/umiche},
    year = {2024},
}
```

## 🏠 Homepage
[📍Oxford NDORMS](https://www.ndorms.ox.ac.uk/team/jianfeng-sun) 

## 📧 Reach us
[![Linkedin Badge](https://img.shields.io/badge/-Jianfeng_Sun-blue?style=flat-square&logo=Linkedin&logoColor=white&link=https://www.linkedin.com/in/jianfeng-sun-2ba9b1132)](https://www.linkedin.com/in/jianfeng-sun-2ba9b1132) 
[![Gmail Badge](https://img.shields.io/badge/-jianfeng.sunmt@gmail.com-c14438?style=flat-square&logo=Gmail&logoColor=white&link=mailto:jianfeng.sunmt@gmail.com)](mailto:jianfeng.sunmt@gmail.com)
[![Outlook Badge](https://img.shields.io/badge/jianfeng.sun@ndorms.ox.ac.uk--000?style=social&logo=microsoft-outlook&logoColor=0078d4&link=mailto:jianfeng.sun@ndorms.ox.ac.uk)](mailto:jianfeng.sun@ndorms.ox.ac.uk)
<a href="https://twitter.com/Jianfeng_Sunny" ><img src="https://img.shields.io/twitter/follow/Jianfeng_Sunny.svg?style=social" /> </a>
